---
name: Bug report
about: Create a report to help us reproduce and correct the bug
title: ''
labels: 'bug'
assignees: ''
---

<!--
Before submitting a bug, please make sure the issue hasn't been already
addressed by searching through the past issues.
-->

#### Describe the bug

<!--
A clear and concise description of what the bug is.
-->

#### Steps/Code to Reproduce

<!--
Please add a minimal example to reproduce the error by running the code.
Please, be as succinct as possible and do not depend on external data. In
short, we would like to be able to copy-paste your code and get the same
result as you.

If the code is too long, feel free to put it in a public gist and link it in
the issue: https://gist.github.com
-->

    Sample code to reproduce the problem

#### Expected Results

<!-- Example: No error is thrown. Please paste or describe the expected results.-->

#### Actual Results

<!-- Please paste or specifically describe the actual output or traceback. -->

#### Versions

<!--
Please run the following snippet and paste the output below.

import groupyr as gpr
print(gpr.__version__)
-->

<!-- Thanks for contributing! -->
